@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="uk_UA">
+<TS version="2.1" language="uk_UA">
 <context>
     <name>AboutDialog</name>
     <message>
@@ -259,9 +259,13 @@ Reason:
         <translation>Адреса</translation>
     </message>
     <message>
-        <source>Toolbar Menu</source>
+        <source>Bookmarks Toolbar</source>
         <translation>Панель закладок</translation>
     </message>
+    <message>
+        <source>Toolbar Menu</source>
+        <translation type="vanished">Панель закладок</translation>
+    </message>
     <message>
         <source>Bookmarks Menu</source>
         <translation>Меню закладок</translation>
@@ -830,76 +834,76 @@ Reason:
     <name>InstallDialog</name>
     <message>
         <source>Install Documentation</source>
-        <translation>Встановити документацію</translation>
+        <translation type="vanished">Встановити документацію</translation>
     </message>
     <message>
         <source>Available Documentation:</source>
-        <translation>Доступна документація:</translation>
+        <translation type="vanished">Доступна документація:</translation>
     </message>
     <message>
         <source>Install</source>
-        <translation>Встановити</translation>
+        <translation type="vanished">Встановити</translation>
     </message>
     <message>
         <source>Cancel</source>
-        <translation>Скасувати</translation>
+        <translation type="vanished">Скасувати</translation>
     </message>
     <message>
         <source>Close</source>
-        <translation>Закрити</translation>
+        <translation type="vanished">Закрити</translation>
     </message>
     <message>
         <source>Installation Path:</source>
-        <translation>Шлях встановлення:</translation>
+        <translation type="vanished">Шлях встановлення:</translation>
     </message>
     <message>
         <source>...</source>
-        <translation>...</translation>
+        <translation type="vanished">...</translation>
     </message>
     <message>
         <source>Downloading documentation info...</source>
-        <translation>Звантажую інформацію про документацію...</translation>
+        <translation type="vanished">Звантажую інформацію про документацію...</translation>
     </message>
     <message>
         <source>Download canceled.</source>
-        <translation>Звантаження скасоване.</translation>
+        <translation type="vanished">Звантаження скасоване.</translation>
     </message>
     <message>
         <source>Done.</source>
-        <translation>Виконано.</translation>
+        <translation type="vanished">Виконано.</translation>
     </message>
     <message>
         <source>The file %1 already exists. Do you want to overwrite it?</source>
-        <translation>Файл %1 вже існує. Бажаєте перезаписати?</translation>
+        <translation type="vanished">Файл %1 вже існує. Бажаєте перезаписати?</translation>
     </message>
     <message>
         <source>Unable to save the file %1: %2.</source>
-        <translation>Неможливо зберегти файл %1: %2.</translation>
+        <translation type="vanished">Неможливо зберегти файл %1: %2.</translation>
     </message>
     <message>
         <source>Downloading %1...</source>
-        <translation>Звантажую %1...</translation>
+        <translation type="vanished">Звантажую %1...</translation>
     </message>
     <message>
         <source>Download failed: %1.</source>
-        <translation>Звантаження провалилось: %1.</translation>
+        <translation type="vanished">Звантаження провалилось: %1.</translation>
     </message>
     <message>
         <source>Documentation info file is corrupt!</source>
-        <translation>Файл інформації про документацію пошкоджений!</translation>
+        <translation type="vanished">Файл інформації про документацію пошкоджений!</translation>
     </message>
     <message>
         <source>Download failed: Downloaded file is corrupted.</source>
-        <translation>Звантаження провалилось: Звантажений файл пошкоджений.</translation>
+        <translation type="vanished">Звантаження провалилось: Звантажений файл пошкоджений.</translation>
     </message>
     <message>
         <source>Installing documentation %1...</source>
-        <translation>Встановлюю документацію %1...</translation>
+        <translation type="vanished">Встановлюю документацію %1...</translation>
     </message>
     <message>
         <source>Error while installing documentation:
 %1</source>
-        <translation>Помилка під час встановлення документації:
+        <translation type="vanished">Помилка під час встановлення документації:
 %1</translation>
     </message>
 </context>
@@ -1101,9 +1105,13 @@ Reason:
         <source>Could not find the associated content item.</source>
         <translation>Не вдалось знайти елемент, пов&apos;язаний зі змістом.</translation>
     </message>
+    <message>
+        <source>&lt;center&gt;&lt;h3&gt;%1&lt;/h3&gt;&lt;p&gt;Version %2&lt;/p&gt;&lt;/center&gt;&lt;p&gt;Copyright (C) %3 Digia Plc and/or its subsidiary(-ies).&lt;/p&gt;</source>
+        <translation>&lt;center&gt;&lt;h3&gt;%1&lt;/h3&gt;&lt;p&gt;Версія %2&lt;/p&gt;&lt;/center&gt;&lt;p&gt;Copyright (C) %3 Digia Plc та/або її дочірні компанії.&lt;/p&gt;</translation>
+    </message>
     <message>
         <source>&lt;center&gt;&lt;h3&gt;%1&lt;/h3&gt;&lt;p&gt;Version %2&lt;/p&gt;&lt;/center&gt;&lt;p&gt;Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).&lt;/p&gt;</source>
-        <translation>&lt;center&gt;&lt;h3&gt;%1&lt;/h3&gt;&lt;p&gt;Версія %2&lt;/p&gt;&lt;/center&gt;&lt;p&gt;Copyright (C) 2013 Digia Plc та/або її дочірні компанії.&lt;/p&gt;</translation>
+        <translation type="vanished">&lt;center&gt;&lt;h3&gt;%1&lt;/h3&gt;&lt;p&gt;Версія %2&lt;/p&gt;&lt;/center&gt;&lt;p&gt;Copyright (C) 2013 Digia Plc та/або її дочірні компанії.&lt;/p&gt;</translation>
     </message>
     <message>
         <source>&lt;center&gt;&lt;h3&gt;%1&lt;/h3&gt;&lt;p&gt;Version %2&lt;/p&gt;&lt;/center&gt;&lt;p&gt;Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).&lt;/p&gt;</source>
